@@ -1245,6 +1245,47 @@ class Client(object):
 
         return decisions
 
+    def get_sliding_window_scores_bulk(self, payload):
+        """Get a group of validation scores of sliding windows.
+
+        :param list payload: Contains the informations to get the validation score. It's in
+        the form [{"id": generator_id, "test_from": test_from, "test_to": test_to, "step": step}]
+        With parameters having the form given in the craft_ai documentation.
+
+        :return: list of scores.
+        :rtype: list of dict.
+
+        :raises CraftAiBadRequestError: If the payload is invalid.
+        """
+
+        # Create the json file with the agents with valid id and send it
+        scores = self._create_and_send_json_bulk(
+            payload, "{}/bulk/generators/score/sliding".format(self._base_url), "POST",
+        )
+
+        return scores
+
+    def get_single_window_score_bulk(self, payload):
+        """Get a group of validation scores of manual defined windows.
+
+        :param list payload: Contains the informations to get the validation score. It's in
+        the form [{"id": generator_id, "test_from": test_from, "test_to": test_to,
+        "model_timestamp": model_timestamp}]
+        With parameters having the form given in the craft_ai documentation.
+
+        :return: list of scores.
+        :rtype: list of dict.
+
+        :raises CraftAiBadRequestError: If the payload is invalid.
+        """
+
+        # Create the json file with the agents with valid id and send it
+        scores = self._create_and_send_json_bulk(
+            payload, "{}/bulk/generators/score/single".format(self._base_url), "POST",
+        )
+
+        return scores
+
     @staticmethod
     def _parse_body(response):
         try:
