@@ -5,6 +5,7 @@ from .. import Client as VanillaClient
 from .. import Time
 from ..constants import DEFAULT_DECISION_TREE_VERSION
 from ..errors import CraftAiBadRequestError
+from ..types import GENERATED_TIME_TYPES
 from .interpreter import Interpreter
 from .utils import format_input, is_valid_property_value, create_timezone_df
 
@@ -241,11 +242,11 @@ class Client(VanillaClient):
 
         return df, tz_col
 
-    def _generate_time_features(self, params, context):
+    def _generate_time_from_context(self, params):
         time = Time(
             t=params["context_ops"][0].value
             // 1000000000,  # Timestamp.value returns nanoseconds
-            timezone=context[params["tz_col"]]
+            timezone=getattr(params["context_ops"], params["tz_col"])
             if params["tz_col"]
             else params["context_ops"][0].tz,
         )
@@ -267,25 +268,32 @@ class Client(VanillaClient):
 
         return decide_context
 
-    def _check_context_properties(self, params):
-        context = {
-            feature_name: format_input(value)
-            for feature_name, value in zip(
-                params["feature_names"], params["context_ops"][1:]
-            )
-            if is_valid_property_value(feature_name, value)
-        }
+    def _format_context(self, params):
+        context = {}
+        for feature in params["feature_names"]:
+            # Skip generated features in the context
+            feature_configuration = params["configuration"]["context"][feature]
+            has_generated_key = "is_generated" in list(feature_configuration.keys())
+            if feature_configuration["type"] in GENERATED_TIME_TYPES and (
+                (has_generated_key and feature_configuration["is_generated"])
+                # If is_generated is not given, by default it is considered True
+                or not has_generated_key
+            ):
+                continue
+
+            value = getattr(params["context_ops"], feature)
+            if is_valid_property_value(feature, value):
+                context[feature] = format_input(value)
         return context
 
     def _pandas_agent_boosting_decide_from_df(
         self, agent_id, from_ts, to_ts, params, df
     ):
         decisions_payload = []
-
-        for row in df.itertuples(name=None):
+        for row in df.itertuples(name="column_names"):
             params["context_ops"] = row
-            context = self._check_context_properties(params)
-            time = self._generate_time_features(params, context)
+            context = self._format_context(params)
+            time = self._generate_time_from_context(params)
             decide_context = self._generate_decision_context(params, context, time)
 
             decisions_payload.append(
@@ -314,6 +322,11 @@ class Client(VanillaClient):
         predictions_df_list = []
         Client.check_decision_context_df(contexts_df)
         configuration = self.get_agent(agent_id)["configuration"]
+        feature_names = [
+            feature
+            for feature in configuration["context"].keys()
+            if feature not in configuration["output"]
+        ]
 
         chunk_size = self.config["operationsChunksSize"]
         for chunk in chunker(contexts_df, chunk_size):
@@ -326,7 +339,7 @@ class Client(VanillaClient):
                 to_ts,
                 {
                     "configuration": configuration,
-                    "feature_names": chunk.columns.values,
+                    "feature_names": feature_names,
                     "tz_col": tz_col,
                 },
                 df,
@@ -341,11 +354,10 @@ class Client(VanillaClient):
         self, generator_id, from_ts, to_ts, params, df
     ):
         decisions_payload = []
-
-        for row in df.itertuples(name=None):
+        for row in df.itertuples(name="column_names"):
             params["context_ops"] = row
-            context = self._check_context_properties(params)
-            time = self._generate_time_features(params, context)
+            context = self._format_context(params)
+            time = self._generate_time_from_context(params)
             decide_context = self._generate_decision_context(params, context, time)
 
             decisions_payload.append(
@@ -376,7 +388,11 @@ class Client(VanillaClient):
         predictions_df_list = []
         Client.check_decision_context_df(contexts_df)
         configuration = self.get_generator(generator_id)["configuration"]
-
+        feature_names = [
+            feature
+            for feature in configuration["context"].keys()
+            if feature not in configuration["output"]
+        ]
         chunk_size = self.config["operationsChunksSize"]
         for chunk in chunker(contexts_df, chunk_size):
             df, tz_col = self._generate_decision_df_and_tz_col(
@@ -389,7 +405,7 @@ class Client(VanillaClient):
                 to_ts,
                 {
                     "configuration": configuration,
-                    "feature_names": df.columns.values,
+                    "feature_names": feature_names,
                     "tz_col": tz_col,
                 },
                 df,
